@@ -1,6 +1,5 @@
 from statsmodels.nonparametric.kernel_regression import KernelReg
 from typing import Tuple, List
-from collections import OrderedDict
 from random import randint, shuffle
 from dataclasses import dataclass
 import numpy as np
@@ -17,7 +16,7 @@ class Estimator:
     def __init__(
         self,
         design_point_evaluator: DesignPointEvaluator,
-        free_parameters_range: OrderedDict[str, Tuple[int, int]],
+        free_parameters_range,  # OrderedDict[str, Tuple[int, int]],
         dataset_size: int,
     ):
         self.__examples: List[Example] = []
@@ -46,7 +45,7 @@ class Estimator:
         print("EXAMPLES: " + str(self.__examples))
 
     def __generate_dataset(
-        self, parameters_range: OrderedDict[str, Tuple[int, int]],
+        self, parameters_range  # : OrderedDict[str, Tuple[int, int]],
     ) -> None:
         for i in range(0, self.__dataset_size):
             design_point = []
